==> valentina_0.7.52~dfsg.orig.tar.xz: valentina-v0.7.52/src/libs/vwidgets/fancytabbar/fancytab.cpp <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "fancytab.h"

#include <QWidget>

//---------------------------------------------------------------------------------------------------------------------
FancyTab::FancyTab(QWidget *tabbar)
    : m_icon(),
      m_text(),
      m_toolTip(),
      m_enabled(false),
      m_Animator(),
      m_TabBar(tabbar),
      m_Fader(0)
{
    m_Animator.setPropertyName("fader");
    m_Animator.setTargetObject(this);
}

//---------------------------------------------------------------------------------------------------------------------
double FancyTab::fader()
{
    return m_Fader;
}

//---------------------------------------------------------------------------------------------------------------------
void FancyTab::fadeIn()
{
    m_Animator.stop();
    m_Animator.setDuration(80);
    m_Animator.setEndValue(40);
    m_Animator.start();
}

//---------------------------------------------------------------------------------------------------------------------
void FancyTab::fadeOut()
{
    m_Animator.stop();
    m_Animator.setDuration(160);
    m_Animator.setEndValue(0);
    m_Animator.start();
}

//---------------------------------------------------------------------------------------------------------------------
void FancyTab::setFader(double value)
{
    m_Fader = value;
    m_TabBar->update();
}

==> valentina_0.7.53~dfsg.orig.tar.xz: valentina-v0.7.53/src/libs/vwidgets/fancytabbar/fancytab.cpp <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "fancytab.h"

#include <QWidget>

//---------------------------------------------------------------------------------------------------------------------
FancyTab::FancyTab(QWidget *tabbar)
  : m_TabBar(tabbar)
{
    m_Animator.setPropertyName("fader");
    m_Animator.setTargetObject(this);
}

//---------------------------------------------------------------------------------------------------------------------
auto FancyTab::fader() const -> double
{
    return m_Fader;
}

//---------------------------------------------------------------------------------------------------------------------
void FancyTab::fadeIn()
{
    m_Animator.stop();
    m_Animator.setDuration(80);
    m_Animator.setEndValue(40);
    m_Animator.start();
}

//---------------------------------------------------------------------------------------------------------------------
void FancyTab::fadeOut()
{
    m_Animator.stop();
    m_Animator.setDuration(160);
    m_Animator.setEndValue(0);
    m_Animator.start();
}

//---------------------------------------------------------------------------------------------------------------------
void FancyTab::setFader(double value)
{
    m_Fader = value;
    m_TabBar->update();
}
